@@ -8,6 +8,8 @@ extern crate log;
 
 mod configuration;
 
+const PODMAN: &str = "podman";
+
 fn main() -> Result<()> {
     let loglevel = get_log_level();
     simple_log::quick!(loglevel);
@@ -45,16 +47,30 @@ fn main() -> Result<()> {
     let config = configuration::build_configuration(basename);
     debug!("config = {:?}", config);
 
+    let engine = PODMAN;
+
+    // selinux labeling does not work on macos yet, changing volume mount argument there for now
+    let volume_mount_parameter = match cfg!(target_os = "macos") && engine == PODMAN {
+        true => {
+            warn!(
+                "MacOS with podman detected, selinux labeling for volumes disabled. \
+                See https://github.com/containers/podman/issues/13631#issuecomment-1077643246 \
+                for more info"
+            );
+            format!("--volume={}:{}", path.to_str().unwrap(), &config.mountpoint)
+        }
+        false => format!(
+            "--volume={}:{}:Z",
+            path.to_str().unwrap(),
+            &config.mountpoint
+        ),
+    };
     // container runtime args are the full list of arguments pass to the container runtime engine
     let mut container_engine_args = vec![
         "run".to_string(),
         "--rm".to_string(),
         "-it".to_string(),
-        format!(
-            "--volume={}:{}:Z",
-            path.to_str().unwrap(),
-            &config.mountpoint
-        ),
+        volume_mount_parameter,
         format!("--workdir={}", config.mountpoint),
     ];
 
@@ -64,7 +80,6 @@ fn main() -> Result<()> {
     full_args.push(config.image);
     full_args.append(&mut target_args);
 
-    let engine = "podman";
     // exec the container command and hand over execution
     debug!(
         "assembled exec command \"{} {}\"",
